@@ -19,13 +19,11 @@ class ExtraTreesEdgePrediction(SklearnEdgePredictionAdapter):
         max_features="auto",
         max_leaf_nodes=None,
         min_impurity_decrease=0.,
-        min_impurity_split=None,
         bootstrap=True,
         oob_score=False,
         n_jobs=-1,
         verbose=0,
         warm_start=False,
-        class_weight=None,
         ccp_alpha=0.0,
         max_samples=None,
         edge_embedding_method: str = "Concatenate",
@@ -46,14 +44,12 @@ class ExtraTreesEdgePrediction(SklearnEdgePredictionAdapter):
         self._max_features = max_features
         self._max_leaf_nodes = max_leaf_nodes
         self._min_impurity_decrease = min_impurity_decrease
-        self._min_impurity_split = min_impurity_split
         self._bootstrap = bootstrap
         self._oob_score = oob_score
         self._n_jobs = n_jobs
         self._random_state = random_state
         self._verbose = verbose
         self._warm_start = warm_start
-        self._class_weight = class_weight
         self._ccp_alpha = ccp_alpha
         self._max_samples = max_samples
 
@@ -68,14 +64,12 @@ class ExtraTreesEdgePrediction(SklearnEdgePredictionAdapter):
                 max_features=max_features,
                 max_leaf_nodes=max_leaf_nodes,
                 min_impurity_decrease=min_impurity_decrease,
-                min_impurity_split=min_impurity_split,
                 bootstrap=bootstrap,
                 oob_score=oob_score,
                 n_jobs=n_jobs,
                 random_state=random_state,
                 verbose=verbose,
                 warm_start=warm_start,
-                class_weight=class_weight,
                 ccp_alpha=ccp_alpha,
                 max_samples=max_samples
             ),
@@ -110,14 +104,12 @@ class ExtraTreesEdgePrediction(SklearnEdgePredictionAdapter):
                 max_features = self._max_features,
                 max_leaf_nodes = self._max_leaf_nodes,
                 min_impurity_decrease = self._min_impurity_decrease,
-                min_impurity_split = self._min_impurity_split,
                 bootstrap = self._bootstrap,
                 oob_score = self._oob_score,
                 n_jobs = self._n_jobs,
                 random_state = self._random_state,
                 verbose = self._verbose,
                 warm_start = self._warm_start,
-                class_weight = self._class_weight,
                 ccp_alpha = self._ccp_alpha,
                 max_samples = self._max_samples,
             )
