@@ -3,7 +3,10 @@ from embiggen.embedders.ensmallen_embedders import *
 from embiggen.embedders.tensorflow_embedders import *
 from embiggen.embedders.pykeen_embedders import *
 from embiggen.embedders.non_existent_embedders import *
+from embiggen.embedders.pytorch_geometric import *
 from embiggen.embedders.karateclub_embedders import *
+from embiggen.embedders.pecanpy_embedders import *
+from embiggen.embedders.fastnode2vec_embedders import *
 from embiggen.embedders.graph_embedding_pipeline import embed_graph
 
 # Export all non-internals.
