@@ -29,7 +29,8 @@ class Node2VecCBOWEnsmallen(Node2VecEnsmallen):
         random_state: int = 42,
         dtype: str = "f32",
         ring_bell: bool = False,
-        enable_cache: bool = False
+        enable_cache: bool = False,
+        verbose: bool = True
     ):
         """Create new abstract Node2Vec method.
 
@@ -100,6 +101,13 @@ class Node2VecCBOWEnsmallen(Node2VecEnsmallen):
         enable_cache: bool = False
             Whether to enable the cache, that is to
             store the computed embedding.
+        verbose: bool = True
+            Whether to display the loading bar.
+            This will only display the loading bar when
+            running the script in a bash-like environment.
+            It will not work in Jupyter Notebooks, there
+            it will appear in the notebook kernel in some
+            systems but not necessarily.
         """
         super().__init__(
             embedding_size=embedding_size,
@@ -123,7 +131,8 @@ class Node2VecCBOWEnsmallen(Node2VecEnsmallen):
             dtype=dtype,
             random_state=random_state,
             ring_bell=ring_bell,
-            enable_cache=enable_cache
+            enable_cache=enable_cache,
+            verbose=verbose,
         )
     
     def parameters(self) -> Dict[str, Any]:
